@@ -6,7 +6,7 @@
 ## This code is free software; you can redistribute it and/or modify
 ## it under the same terms as Perl itself.
 ##
-## $Id: Random.pm,v 1.8 2001/06/22 18:16:28 vipul Exp $
+## $Id: Random.pm,v 1.10 2001/07/09 17:42:34 vipul Exp $
 
 package Crypt::Random; 
 require Exporter;
@@ -19,7 +19,7 @@ use Crypt::Random::Generator;
 *import      = \&Exporter::import;
 
 @EXPORT_OK   = qw( makerandom makerandom_itv makerandom_octet );
-($VERSION) = do { my @r = (q$Revision: 1.8 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+($VERSION) = do { my @r = (q$Revision: 1.10 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 
 sub _pickprovider { 
@@ -27,8 +27,8 @@ sub _pickprovider {
     my (%params) = @_;
 
     return $params{Provider} if $params{Provider};
-    $strength = 0 unless $params{Strength};
-    my $gen = new Crypt::Random::Generator Strength => $strength;
+    $params{Strength} ||= 0;
+    my $gen = new Crypt::Random::Generator Strength => $params{Strength};
     return $gen->{Provider};
 
 }
@@ -101,8 +101,8 @@ Crypt::Random - Cryptographically Secure, True Random Number Generator.
 
 =head1 VERSION
 
- $Revision: 1.8 $
- $Date: 2001/06/22 18:16:28 $
+ $Revision: 1.10 $
+ $Date: 2001/07/09 17:42:34 $
 
 =head1 SYNOPSIS
 
@@ -217,3 +217,4 @@ Vipul Ved Prakash, <mail@vipul.net>
 
 =cut
 
+
